;; Generated package description from marginalia.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "marginalia" "2.12" "Enrich existing commands with completion annotations" '((emacs "29.1") (compat "31")) :commit "7ec0b70afb43a756ecd45a958c6ebe797717fc91" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("docs" "help" "matching" "completion") :url "https://github.com/minad/marginalia")
